@@ -37,14 +37,12 @@
 "use strict";
 
 define ([
+    'app/caches',
     'app/act-lib',
-    'app/emp-lib',
-    'app/sched-lib',
     'datetime',
 ], function (
+    appCaches,
     actLib,
-    empLib,
-    schedLib,
     datetime,
 ) {
 
@@ -114,12 +112,20 @@ define ([
             prop: 'privEffective',
             maxlen: 30,
         },
-        ePsched: {
-            name: 'ePsched',
+        ePscode: {
+            name: 'ePscode',
             aclProfileRead: 'inactive',
             aclProfileWrite: 'admin',
-            text: 'Schedule',
-            prop: 'sched',
+            text: 'Schedule code',
+            prop: 'scode',
+            maxlen: 20,
+        },
+        ePsid: {
+            name: 'ePsid',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Schedule ID',
+            prop: 'sid',
             maxlen: 20,
         },
         ePschedEffective: {
@@ -137,7 +143,7 @@ define ([
             text: 'Supervisor',
             prop: 'ePsuperNick',
             maxlen: 30,
-            populate: empLib.populateSupervisorNick,
+            populate: appCaches.populateSupervisorNick,
         },
         LDAPdochazka: {
             name: 'LDAPdochazka',
@@ -349,7 +355,7 @@ define ([
             text: 'Schedule ID',
             prop: 'iNsid',
             maxlen: 20,
-            // populate: schedLib.populateSID,
+            populate: appCaches.populateSIDByDate,
         },
         iNoffset: {
             name: 'iNoffset',
@@ -374,7 +380,7 @@ define ([
             text: 'Activity ID',
             prop: 'aid',
             maxlen: 6,
-            populate: actLib.populateAIDfromCode,
+            populate: appCaches.populateAIDfromCode,
         },
         acTdesc: {
             name: 'acTdesc',
@@ -391,7 +397,7 @@ define ([
             text: 'Scheduled',
             prop: 'iNschedintvls',
             maxlen: 50,
-            // populate: schedLib.populateSchedIntvlsForDate,
+            populate: appCaches.populateSchedIntvlsForDate,
         },
         iNlastexistintvl: {
             name: 'iNlastexistintvl',
