@@ -37,9 +37,9 @@
 "use strict";
 
 define ([
-    'jquery',
-    'target',
     'app/act-lib',
+    'app/caches',
+    'app/emp-lib',
     'app/daction-init',
     'app/dform-init',
     'app/dmenu-init',
@@ -48,11 +48,12 @@ define ([
     'app/dtable-init',
     'app/drowselect-init',
     'init2',
-    'stack'
+    'populate',
+    'stack',
 ], function (
-    $,
-    target,
     actLib,
+    appCaches,
+    empLib,
     dactionInitRoundOne,
     dformInitRoundOne,
     dmenuInitRoundOne,
@@ -61,46 +62,39 @@ define ([
     dtableInitRoundOne,
     drowselectInitRoundOne,
     initRoundTwo,
-    stack
+    populate,
+    stack,
 ) {
 
     return function () {
 
         // round one - set up the targets
         console.log("dochazka-www/target-init.js: round one");
-        $('#mainarea').html("Loading dactions");
         dactionInitRoundOne();
-        $('#mainarea').html("Loading dforms");
         dformInitRoundOne();
-        $('#mainarea').html("Loading dmenus");
         dmenuInitRoundOne();
-        $('#mainarea').html("Loading dbrowsers");
         dbrowserInitRoundOne();
-        $('#mainarea').html("Loading dnotices");
         dnoticeInitRoundOne();
-        $('#mainarea').html("Loading dtables");
         dtableInitRoundOne();
-        $('#mainarea').html("Loading drowselects");
         drowselectInitRoundOne();
 
         // round two - add 'source' and 'start' properties
         // (widget targets only)
         console.log("dochazka-www/target-init.js: round two");
-        $('#mainarea').html("Initializing dforms");
         initRoundTwo('dform');
-        $('#mainarea').html("Initializing dmenus");
         initRoundTwo('dmenu');
-        $('#mainarea').html("Initializing dbrowsers");
         initRoundTwo('dbrowser');
-        $('#mainarea').html("Initializing dnotices");
         initRoundTwo('dnotice');
-        $('#mainarea').html("Initializing dtables");
         initRoundTwo('dtable');
-        $('#mainarea').html("Initializing drowselects");
         initRoundTwo('drowselect');
 
-        // populate activities cache
-        actLib.populateActivitiesCache();
+        // use "populate" pattern to populate caches
+        // (activities, full employee profile)
+        populate([
+            appCaches.populateFullEmployeeProfileCache,
+            appCaches.populateScheduleBySID,
+            appCaches.populateActivityCache,
+        ]);
 
         // fire up the main menu
         stack.push('mainMenu');
